/*
 * [Scheme.java]
 *
 * Summary: Colour scheme for CurrCon applet.
 *
 * Copyright: (c) 2001-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  3.5 2008-09-19 allow commas in parameter amount values.
 */
package com.mindprod.currcon;

import com.mindprod.common18.Build;

import java.awt.Color;

/**
 * Colour scheme for CurrCon applet.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 3.5 2008-09-19 allow commas in parameter amount values.
 * @since 2001
 */
final class Scheme
    {
    /**
     * match mindprod background to make appear transparent
     */
    static final Color BACKGROUND_FOR_COMPACT_AMOUNT = new Color( 0xf6fff6 )/* pale green, matches CMP background */;

    /**
     * background for fixed currency code display (not selector)
     */
    static final Color BACKGROUND_FOR_CURRENCY_CODE = new Color( 0xc5d3df ); // pale version of L&F Currency selector

    /**
     * background for currency name display
     */
    static final Color BACKGROUND_FOR_CURRENCY_NAME = Color.white;

    /**
     * background for currency code selector
     */
    static final Color BACKGROUND_FOR_CURRENCY_SELECTOR = Color.white;
    // color

    /**
     * background for invalid. should never show. Should be bright to point out error
     */
    static final Color BACKGROUND_FOR_INVALID = Color.yellow;

    /**
     * match mindprod background to make appear transparent
     */
    static final Color BACKGROUND_FOR_PRECISE_AMOUNT = Build.BACKGROUND_FOR_BLENDING;

    /**
     * amount foreground
     */
    static final Color FOREGROUND_FOR_COMPACT_AMOUNT = new Color( 0x191970 )/* midnight blue */;

    /**
     * foreground for fixed currency code display (not selector)
     */
    static final Color FOREGROUND_FOR_CURRENCY_CODE = new Color( 0x8b7a11 /*! tarnished gold !*/ );

    /**
     * foreground for currency name display
     */
    static final Color FOREGROUND_FOR_CURRENCY_NAME = new Color( 0x8b7a11 /*! tarnished gold !*/ );

    /**
     * foreground for currency code selector
     */
    static final Color FOREGROUND_FOR_CURRENCY_SELECTOR = new Color( 0x8b7a11 /*! tarnished gold !*/ );

    /**
     * foreground for invalid. should never show. Should be bright to point out error
     */
    static final Color FOREGROUND_FOR_INVALID = Color.RED;

    /**
     * amount foreground
     */
    static final Color FOREGROUND_FOR_PRECISE_AMOUNT = new Color( 0x191970 )/* midnight blue */;

    private static final boolean DEBUGGING = false;

    /**
     * Applet color.  If it shows through, that indicates an error.
     */
    static final Color BACKGROUND_FOR_APPLET = DEBUGGING ? Color.GREEN : Build.BACKGROUND_FOR_BLENDING;
    }
